@@ -674,9 +674,10 @@ class LiLit(Likelihood):
             print(f"Keys of fiducial CLs ---> {self.fiduCLS.keys()}")
             print(f"Keys of noise CLs ---> {self.noiseCLS.keys()}")
 
-            field = "yy"
             print("\nPrinting the first few values to check that it starts from 0...")
+            field = self.fiduCLS.keys()[0]
             print(f"Fiducial CLs for {field.upper()} ---> {self.fiduCLS[field][0:5]}")
+            field = self.noiseCLS.keys()[0]
             print(f"Noise CLs for {field.upper()} ---> {self.noiseCLS[field][0:5]}")
 
         # Compute the total covariance matrix
@@ -819,7 +820,7 @@ class LiLit(Likelihood):
         if self.debug:
             print(f"Keys of Cobaya CLs ---> {self.cobaCLs.keys()}")
 
-            field = "yy"
+            field = self.cobaCLs.keys()[0]
             print("\nPrinting the first few values to check that it starts from 0...")
             print(f"Cobaya CLs for {field.upper()} ---> {self.cobaCLs[field][0:5]}")
 
